.. _gal-topography:

Topography
==========

This section provides examples of how to use the :ref:`api-surface` and :ref:`api-morphology` components of Cratermaker to model the surface topography of craters and the topographic evolution of cratered surfaces.
